@@ -8,6 +8,7 @@ Last modified: 2018-06-03 00:38:17
 import datetime
 import hashlib
 import random
+import re
 import uuid
 
 import tornado.web
@@ -65,7 +66,7 @@ class BaseHandler(BaseHandler):
             return Dict({'err': 1, 'msg': '请输入Email'})
         if len(email) > 64:
             return Dict({'err': 1, 'msg': 'Email地址太长'})
-        if not email.find('@') >= 0:
+        if not re.match(r'.*@(.*)\.(\w+)$', email):
             return Dict({'err': 1, 'msg': '请填写正确的Email格式'})
         if await awaitable(self.db.users.find_one({'email': email})):
             return Dict({'err': 1, 'msg': 'Email地址重复'})
@@ -91,16 +92,18 @@ class BaseHandler(BaseHandler):
                 if self.current_user:
                     ret.active = True
                     ret.token = self.current_user.token
-                    await awaitable(self.db.users.update_one({'_id': self.current_user._id}, {'$set': ret}))
+                    keys = ['active', 'openId', 'avatarUrl', 'city', 'country', 'gender', 'language', 'nickName', 'province']
+                    update = {k: v for k, v in ret.items() if k in keys}
+                    await awaitable(self.db.users.update_one({'_id': self.current_user._id}, {'$set': update}))
                 else:
                     ret.id = await awaitable(self.db.users.seq_id)
                     ret.token = uuid.uuid4().hex
                     ret.active = True
                     ret.created_at = datetime.datetime.now().replace(microsecond=0)
-                    ret.vip = 3
-                    ret.vip1_expired_at = ret.created_at + datetime.timedelta(days=1)
-                    ret.vip2_expired_at = ret.created_at + datetime.timedelta(days=1)
-                    ret.vip3_expired_at = ret.created_at + datetime.timedelta(days=1)
+                    # ret.vip = 3
+                    # ret.vip1_expired_at = ret.created_at + datetime.timedelta(days=1)
+                    # ret.vip2_expired_at = ret.created_at + datetime.timedelta(days=1)
+                    # ret.vip3_expired_at = ret.created_at + datetime.timedelta(days=1)
                     await awaitable(self.db.users.insert_one(ret))
             expires = datetime.datetime.now() + datetime.timedelta(days=30)
             self.set_cookie('token', ret.token, expires=expires)
